@@ -6,70 +6,77 @@ my $celini_table = Slovo::Model::Celini->table;
 
 sub table { return $table }
 
-#Find a page by $alias which is allowed to be seen by the current user
-sub find_for_display ($self, $alias, $user) {
-  my $db  = $self->dbx->db;
+# Find a page by $alias which can be seen by the current user
+sub find_for_display ($m, $alias, $user, $дом, $прегледъ) {
   my $now = time;
+  state $domain_sql = <<"SQL";
+= (SELECT id FROM domove
+    WHERE (? LIKE '%' || domain OR ips like ?) AND published = ? LIMIT 1)
+SQL
 
-  # Get the page
-  return $db->select(
+  return $m->dbx->db->select(
     $table, undef,
     {
-     alias   => $alias,
-     deleted => 0,
-     start   => [{'=' => 0}, {'<' => $now}],
-     stop    => [{'=' => 0}, {'>' => $now}],
+     alias => $alias,
+     $прегледъ ? () : (deleted => 0),
+     $прегледъ ? () : (start   => [{'=' => 0}, {'<' => $now}]),
+     $прегледъ ? () : (stop    => [{'=' => 0}, {'>' => $now}]),
+
+     # the page must belong to the current domain
+     dom_id => \[$domain_sql, => ($дом, "%$дом%", 2)],
 
-     # TODO: implement multidomain support
-     # domain_id => $domain_id
      # TODO: May be drop this column as 'hidden' can be
-     # implemented by putting '.' as first cahracter for the alias.
-     hidden => 0,
-     -or    => [
+     # implemented by putting '.' as first character for the alias.
+     $прегледъ ? () : (hidden => 0),
+
+     -or => [
 
        # published and everybody can read and execute
        # This page can be stored on disk and served as static page
        # after displayed for the first time
        {published => 2, permissions => {-like => '%r_x'}},
-       {    # preview of a page, owned by this user
-         user_id     => $user->{id},
-         permissions => {-like => '_r_x%'},
-       },
-       {    # preview of a page, which can be read and executed
-            # by one of the groups to which this user belongs
-         permissions => {-like => '____r_x%'},
 
-         # TODO: Implement multiple groups for users and then:
-         group_id => {
-              -in => [
-                 $user->{group_id},
-                 \"(SELECT group_id from user_group WHERE user_id=$user->{id})"
-              ]
-         }
+       # preview of a page, owned by this user
+       {user_id => $user->{id}, permissions => {-like => '_r_x%'}},
+
+       # preview of a page, which can be read and executed
+       # by one of the groups to which this user belongs.
+       {
+        permissions => {-like => '____r_x%'},
+        published => $прегледъ ? 1 : 2,
+
+        # TODO: Implement 'adding users to multiple groups':
+        group_id => \[
+           "IN (SELECT group_id from user_group WHERE user_id=?)" => $user->{id}
+        ],
        },
      ]
     }
   )->hash;
-
 }
 
 
 sub add ($m, $row) {
-  $row->{start} //= $row->{tstamp} = time - 1;
+  $row->{tstamp} = time - 1;
+  $row->{start} //= $row->{tstamp};
   my $title = {};
   @$title{qw(title language body)} = delete @$row{qw(title language body)};
-  @$title{qw(sorting data_type created_at user_id group_id changed_by alias)}
-    = (0, 'заглавѥ', @$row{qw(tstamp user_id group_id changed_by alias)});
-  my $id;
+  @$title{
+    qw(sorting data_type created_at user_id
+    group_id changed_by alias permissions published)
+    } = (
+       0, 'заглавѥ',
+       @$row{qw(tstamp user_id 
+       group_id changed_by alias permissions published)}
+        );
   my $db = $m->dbx->db;
   eval {
     my $tx = $db->begin;
-    $id = $db->insert($table, $row)->last_insert_id;
-    $title->{page_id} = $id;
+    $title->{page_id} = $db->insert($table, $row)->last_insert_id;
     $db->insert($celini_table, $title);
     $tx->commit;
   } || Carp::croak("Error creating stranici record: $@");
-  return $id;
+  return $title->{page_id};
 }
 
 
@@ -93,11 +100,15 @@ sub find_for_edit ($self, $id, $language) {
 
 sub save ($m, $id, $row) {
   my $title = {};
-  @$title{qw(page_id title body language id alias changed_by)} = (
-                                 $id,
-                                 delete @$row{qw(title body language title_id)},
-                                 @$row{qw(alias changed_by)}
-  );
+
+  # Get the values for celini
+  @$title{
+    qw(page_id title body language id alias changed_by permissions published)}
+    = (
+       $id,
+       delete @$row{qw(title body language title_id)},
+       @$row{qw(alias changed_by permissions published)}
+      );
   my $db = $m->dbx->db;
   eval {
     my $tx = $db->begin;
